searchData={"items":[{"type":"module","title":"NervesMOTD","doc":"`NervesMOTD` prints a \"message of the day\" on Nerves devices.\n\nTo use, add `NervesMOTD.print()` to the `rootfs_overlay/etc/iex.exs` file in\nyour Nerves project.","ref":"NervesMOTD.html"},{"type":"function","title":"NervesMOTD.print/1","doc":"Print the message of the day\n\nThis uses the Nerves.Runtime library. In the unlikely event that it's not\navailable, it assumes the system isn't ready and doesn't print the MOTD.\n\nOptions:\n\n* `:logo` - a custom logo to display instead of the default Nerves logo. Pass\n  an empty logo (`\"\"`) to remove it completely.\n* `:extra_rows` - a list of custom rows or a callback for returning rows.\n  The callback can be a 0-arity function reference or MFArgs tuple.","ref":"NervesMOTD.html#print/1"},{"type":"type","title":"NervesMOTD.cell/0","doc":"A label and value","ref":"NervesMOTD.html#t:cell/0"},{"type":"type","title":"NervesMOTD.option/0","doc":"MOTD options","ref":"NervesMOTD.html#t:option/0"},{"type":"type","title":"NervesMOTD.row/0","doc":"One row of information\n\nA row may contain 0, 1 or 2 cells.","ref":"NervesMOTD.html#t:row/0"},{"type":"extras","title":"nerves_motd","doc":"# nerves_motd\n\n[![Hex version](https://img.shields.io/hexpm/v/nerves_motd.svg \"Hex version\")](https://hex.pm/packages/nerves_motd)\n[![CircleCI](https://circleci.com/gh/nerves-project/nerves_motd.svg?style=svg)](https://circleci.com/gh/nerves-project/nerves_motd)\n\n`nerves_motd` prints a [\"message of the\nday\"](https://en.wikipedia.org/wiki/Motd_(Unix)) on Nerves devices.\n\n![](https://user-images.githubusercontent.com/7563926/202566900-942f3963-ff0e-48c2-9e13-03f96dd9a0d0.png)","ref":"readme.html"},{"type":"extras","title":"Usage - nerves_motd","doc":"The primary function is `NervesMOTD.print()` which prints the base layout based\non the template below:\n\n```\n \n    ( )    \n  Serial       :  \n  Uptime       : 18.296 seconds\n  Clock        : 2023-05-18 00:05:20 JST  \n\n  Firmware     :   ( )      Applications :   started ( )\n  Memory usage : 74 MB (15%)             Part usage   : 210 MB (14%)\n  Hostname     :                Load average : 0.05 0.14 0.15\n\n        :  ,  \n   \n```\n\nTo have `NervesMOTD` print automatically when first accessing a device, add\n`NervesMOTD.print()` to your `iex.exs` file (typically in\n`rootfs_overlay/etc/iex.exs`)","ref":"readme.html#usage"},{"type":"extras","title":"Customization - nerves_motd","doc":"`NervesMOTD.print/1` supports a few options for customizing the base layout:\n\n* `:logo` - Change the logo displayed. Defaults to the Nerves logo. Set to `\"\"`\n  to prevent any logo from being displayed\n* `:extra_rows` - a list of custom rows or a callback for returning rows to be\n  appended to the end of the layout. The callback can be a 0-arity function\n  reference or MFArgs tuple.\n\nFor convenience, `NervesMOTD.print/1` options may be stored in the application\nenvironment in your `config.exs` to be used whenever `NervesMOTD.print/0` is\ncalled:\n\n```elixir\nconfig :nerves_motd,\n  logo: \"\"\"\n  Custom logo\n  \"\"\",\n  extra_rows: [\n    [{\"Label\", \"value\"}, {\"Label2\", \"value2\"}],\n    [{\"Long label\", \"Lots of text\"}]\n  ]\n```","ref":"readme.html#customization"},{"type":"extras","title":"Installation - nerves_motd","doc":"Install by adding `:nerves_motd` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nerves_motd, \"~> 0.1.0\"}\n  ]\nend\n```\n\nFor details, see [API reference](https://hexdocs.pm/nerves_motd/api-reference.html).","ref":"readme.html#installation"},{"type":"extras","title":"License - nerves_motd","doc":"Copyright (C) 2022 Masatoshi Nishiguchi, Nerves Project Authors\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis project follows [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.1.15 - 2024-07-19 - Changelog","doc":"This release requires Elixir 1.13 or later. Previous versions became hard to\nmaintain due to dependent packages. No code changed in this library to prevent\nprevious versions from working.\n\n* Fixes\n  * Fix a regression that caused the firmware validity to always show up as valid even when invalid.","ref":"changelog.html#v0-1-15-2024-07-19"},{"type":"extras","title":"v0.1.14 - 2024-06-02 - Changelog","doc":"* Improvements\n  * Fix Elixir 1.17 warnings","ref":"changelog.html#v0-1-14-2024-06-02"},{"type":"extras","title":"v0.1.13 - 2023-05-17 - Changelog","doc":"* Improvements\n  * Support `:extra_rows` as a callback (#124)","ref":"changelog.html#v0-1-13-2023-05-17"},{"type":"extras","title":"v0.1.12 - 2023-05-10 - Changelog","doc":"* Improvements\n  * Use application environment for default options (#122)\n  * Use yellow text color for clock and show unsyncronized help text when clock is out of sync (#74)","ref":"changelog.html#v0-1-12-2023-05-10"},{"type":"extras","title":"v0.1.11 - 2023-02-04 - Changelog","doc":"* Bug fixes\n  * Don't raise if `Nerves.Runtime.KV` is empty\n\n* Improvements\n  * Test with ANSI off to make tests easier to read\n  * Update specs to `IO.chardata()` for consistency","ref":"changelog.html#v0-1-11-2023-02-04"},{"type":"extras","title":"v0.1.10 - 2023-02-01 - Changelog","doc":"* Improvements\n  * Print milliseconds when uptime < 60s\n  * Add serial number","ref":"changelog.html#v0-1-10-2023-02-01"},{"type":"extras","title":"v0.1.9 - 2022-11-17 - Changelog","doc":"* Improvements\n  * Append `\"°C\"` to temperature value","ref":"changelog.html#v0-1-9-2022-11-17"},{"type":"extras","title":"v0.1.8 - 2022-10-26 - Changelog","doc":"* Improvements\n  * Show CPU temperature on MOTD\n  * Support OTP 25\n  * Update the Nerves CLI help url\n  * Fix tests with nerves_runtime >= 0.11.9","ref":"changelog.html#v0-1-8-2022-10-26"},{"type":"extras","title":"v0.1.7 - 2022-03-03 - Changelog","doc":"* Improvements\n  * Skip printing MOTD if Nerves.Runtime isn't started. The previous behavior\n    was to try to start Nerves.Runtime. The scenario this mostly affects is\n    printing the MOTD to the serial console right after Elixir loads, but before\n    Nerves.Runtime and the rest. Besides printing a slightly confusing MOTD of a\n    partially started system, it also could reorder OTP application from the\n    boot script.","ref":"changelog.html#v0-1-7-2022-03-03"},{"type":"extras","title":"v0.1.6 - 2021-11-29 - Changelog","doc":"* Improvements\n  * Add `:extra_rows` option to allow users to supply additional information to\n    be printed in the MOTD. The use case for this is to show project-specific\n    information like MQTT connection status in addition to the generic info.","ref":"changelog.html#v0-1-6-2021-11-29"},{"type":"extras","title":"v0.1.5 - 2021-11-02 - Changelog","doc":"* Improvements\n  * Print local time when a time zone has been set with `NervesTimeZones`\n  * Handle exceptions from `NervesMOTD.print/1` so they don't prematurely end\n    `iex.exs` scripts\n  * Handle Nerves configurations that do not have an application data partition\n  * Simplify text handling internally by using Elixir's `ansidata` throughout","ref":"changelog.html#v0-1-5-2021-11-02"},{"type":"extras","title":"v0.1.4 - 2021-10-17 - Changelog","doc":"* Improvements\n  * Improve the logo so that it can render properly on touchscreen","ref":"changelog.html#v0-1-4-2021-10-17"},{"type":"extras","title":"v0.1.3 - 2021-10-10 - Changelog","doc":"* Improvements\n  * Remove denominator (loaded application count) from the applications section because it is changeable and can cause confusion\n  * Change text color for applications not (yet) loaded from red to yellow because most of the time it is transient","ref":"changelog.html#v0-1-3-2021-10-10"},{"type":"extras","title":"v0.1.2 - 2021-09-25 - Changelog","doc":"* Improvements\n  * Show IP addresses assigned to network interfaces","ref":"changelog.html#v0-1-2-2021-09-25"},{"type":"extras","title":"v0.1.1 - 2021-09-15 - Changelog","doc":"* Updates\n  * Refactor the template using `iodata`\n  * Use round instead of trunc for percentage\n  * Update screenshot in readme","ref":"changelog.html#v0-1-1-2021-09-15"},{"type":"extras","title":"v0.1.0 - 2021-09-08 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0-2021-09-08"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}